
require 'time-lib.pl';

sub acl_security_form
{
    print(
	"<tr>",
	    "<td><b>", $text{ 'acl_sys' }, "</b></td>",
	    "<td><input type=radio name=sysdate value=0 ", $_[0] -> { 'sysdate' } == 0 ? "checked" : "", ">", $text{ 'acl_yes' }, " <input type=radio name=sysdate value=1 ", $_[0] -> { 'sysdate' } == 1 ? "checked" : "", ">", $text{ 'acl_no' },
	"</tr><tr>",
	    "<td><b>", $text{ 'acl_hw' }, "</b></td>",
	    "<td><input type=radio name=hwdate value=0 ", $_[0] -> { 'hwdate' } == 0 ? "checked" : "", ">", $text{ 'acl_yes' }, " <input type=radio name=hwdate value=1 ", $_[0] -> { 'hwdate' } == 1 ? "checked" : "", ">", $text{ 'acl_no' },
	"</tr>" );
}

sub acl_security_save
{
    $_[0] -> { 'sysdate' } = $in{ 'sysdate' };
    $_[0] -> { 'hwdate' } = $in{ 'hwdate' };
}
